Modulatory Projections
======================

.. _ModulatoryProjection_Subtypes:

.. toctree::
   :maxdepth: 1

   LearningProjection
   ControlProjection
   GatingProjection

.. automodule:: psyneulink.components.projections.modulatory.modulatoryprojection
   :members:
   :exclude-members: ModulatoryProjection_Base, Linear, random
